



if not exist %PREFIX%\\Library\\share\\dcw-gmt\\LICENSE exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\dcw-gmt\\dcw-gmt.nc exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
